<?php
/*
Plugin Name: ETWP Dropdown Menu Generator
Description: A plugin that adds shortcodes for dropdowns of pages, posts, categories, tags, WooCommerce products, and custom menus. [dropdown_menu id="17" label="placeholder"][dropdown_pages][dropdown_post][dropdown_categories][dropdown_tags][dropdown_woo_products][dropdown_woo_categories][dropdown_woo_tags]
Version: 1.8
Author: EasyToolsWP.com
*/

// Ensure the plugin is not directly accessed
if (!defined('ABSPATH')) {
    exit;
}

// Function to generate dropdown with JavaScript redirect
function generate_dropdown($items, $link_callback, $label = '') {
    if (empty($items)) {
        return '<p>No items in this dropdown</p>'; // Display text if there are no items
    }

    // Create dropdown with a placeholder option or label if set
    $output = '<select onchange="if (this.value) window.location.href=this.value;">';
    $output .= '<option value="" selected disabled>' . esc_html($label) . '</option>'; // Placeholder option
    foreach ($items as $item) {
        $output .= '<option value="' . esc_url(call_user_func($link_callback, $item)) . '">' . esc_html($item->post_title ?? $item->name) . '</option>';
    }
    $output .= '</select>';
    
    return $output;
}

// Dropdown for Pages
function dropdown_pages_shortcode($atts) {
    $atts = shortcode_atts(array('label' => 'Select a page'), $atts); // Placeholder label
    $pages = get_pages();
    return generate_dropdown($pages, function($page) {
        return get_page_link($page->ID);
    }, $atts['label']);
}
add_shortcode('dropdown_pages', 'dropdown_pages_shortcode');

// Dropdown for Posts
function dropdown_post_shortcode($atts) {
    $atts = shortcode_atts(array('label' => 'Select a post'), $atts); // Placeholder label
    $posts = get_posts();
    return generate_dropdown($posts, function($post) {
        return get_permalink($post->ID);
    }, $atts['label']);
}
add_shortcode('dropdown_post', 'dropdown_post_shortcode');

// Dropdown for Categories
function dropdown_categories_shortcode($atts) {
    $atts = shortcode_atts(array('label' => 'Select a category'), $atts); // Placeholder label
    $categories = get_categories();
    return generate_dropdown($categories, function($category) {
        return get_category_link($category->term_id);
    }, $atts['label']);
}
add_shortcode('dropdown_categories', 'dropdown_categories_shortcode');

// Dropdown for Tags
function dropdown_tags_shortcode($atts) {
    $atts = shortcode_atts(array('label' => 'Select a tag'), $atts); // Placeholder label
    $tags = get_tags();
    return generate_dropdown($tags, function($tag) {
        return get_tag_link($tag->term_id);
    }, $atts['label']);
}
add_shortcode('dropdown_tags', 'dropdown_tags_shortcode');

// Dropdown for WooCommerce Products
function dropdown_woo_products_shortcode($atts) {
    if (class_exists('WooCommerce')) {
        $atts = shortcode_atts(array('label' => 'Select a product'), $atts); // Placeholder label
        $products = get_posts(array('post_type' => 'product', 'posts_per_page' => -1));
        return generate_dropdown($products, function($product) {
            return get_permalink($product->ID);
        }, $atts['label']);
    }
    return 'WooCommerce is not installed';
}
add_shortcode('dropdown_woo_products', 'dropdown_woo_products_shortcode');

// Dropdown for WooCommerce Categories
function dropdown_woo_categories_shortcode($atts) {
    if (class_exists('WooCommerce')) {
        $atts = shortcode_atts(array('label' => 'Select a product category'), $atts); // Placeholder label
        $categories = get_terms('product_cat');
        return generate_dropdown($categories, function($category) {
            return get_term_link($category->term_id, 'product_cat');
        }, $atts['label']);
    }
    return 'WooCommerce is not installed';
}
add_shortcode('dropdown_woo_categories', 'dropdown_woo_categories_shortcode');

// Dropdown for WooCommerce Tags
function dropdown_woo_tags_shortcode($atts) {
    if (class_exists('WooCommerce')) {
        $atts = shortcode_atts(array('label' => 'Select a product tag'), $atts); // Placeholder label
        $tags = get_terms('product_tag');
        return generate_dropdown($tags, function($tag) {
            return get_term_link($tag->term_id, 'product_tag');
        }, $atts['label']);
    }
    return 'WooCommerce is not installed';
}
add_shortcode('dropdown_woo_tags', 'dropdown_woo_tags_shortcode');

// Function to get menu items from a custom menu based on menu ID
function get_menu_items_by_menu_id($menu_id) {
    $menu_items = wp_get_nav_menu_items($menu_id);
    if (!$menu_items) {
        return [];
    }
    return $menu_items;
}

// Dropdown for Custom Menu
function dropdown_menu_shortcode($atts) {
    $atts = shortcode_atts(array(
        'id'    => '', // Menu ID must be specified
        'label' => 'Select a menu item' // Placeholder label
    ), $atts);

    $menu_id = $atts['id'];
    $label = $atts['label'];

    if (empty($menu_id)) {
        return '<p>Menu ID is not specified.</p>';
    }

    // Get menu items based on custom menu ID
    $menu_items = wp_get_nav_menu_items($menu_id);

    // If no menu items are found, display a message
    if (empty($menu_items)) {
        return '<p>No items in this dropdown</p>';
    }

    // Create dropdown with a placeholder option or label if set
    $output = '<select onchange="if (this.value) window.location.href=this.value;">';
    $output .= '<option value="" selected disabled>' . esc_html($label) . '</option>'; // Placeholder option

    foreach ($menu_items as $item) {
        // Output menu title correctly
        $output .= '<option value="' . esc_url($item->url) . '">' . esc_html($item->title) . '</option>';
    }

    $output .= '</select>';
    
    return $output;
}
add_shortcode('dropdown_menu', 'dropdown_menu_shortcode');